/*
** Copyright (c) 2001  Hughes Technologies Pty Ltd.  All rights
** reserved.  
**
** Terms under which this software may be used or copied are
** provided in the  specific license associated with this product.
**
** Hughes Technologies disclaims all warranties with regard to this 
** software, including all implied warranties of merchantability and 
** fitness, in no event shall Hughes Technologies be liable for any 
** special, indirect or consequential damages or any damages whatsoever 
** resulting from loss of use, data or profits, whether in an action of 
** contract, negligence or other tortious action, arising out of or in 
** connection with the use or performance of this software.
**
**
** $Id: memory.c,v 1.2 2002/08/15 05:10:27 bambi Exp $
**
*/

/*
** Module	: 
** Purpose	: 
** Exports	: 
** Depends Upon	: 
*/



/**************************************************************************
** STANDARD INCLUDES
**************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <fcntl.h>
#include <sys/types.h>

#include "config/config.h"
#include "ember.h"

#ifdef HAVE_UNISTD_H
#  include <unistd.h>
#endif
#ifdef HAVE_STRING_H
#  include <string.h>
#endif
#ifdef HAVE_STRINGS_H
#  include <strings.h>
#endif


/**************************************************************************
** MODULE SPECIFIC INCLUDES
**************************************************************************/


/**************************************************************************
** GLOBAL VARIABLES
**************************************************************************/


/**************************************************************************
** PRIVATE ROUTINES
**************************************************************************/


/**************************************************************************
** PUBLIC ROUTINES
**************************************************************************/


void *eMemRealMalloc(script, size, file, line)
	ember	*script;
	size_t	size;
	char	*file;
	int	line;
{
	void	*buf;

#	ifdef EMBER_MALLOC_DEBUG
#  		undef malloc
#	endif
	buf = malloc(size);
	if(buf == NULL)
	{
		snprintf(script->errorMsg, EMBER_ERR_LEN,
			"Out of memory at line %d of %s for %d bytes",
			line, file, (int)size);
	}
#	ifdef EMBER_MALLOC_DEBUG
	printf("Malloc(%d) = %d at %s : %d\n",size,buf,file,line);
#	endif
	return(buf);
}

void eMemRealFree(script, ptr, file, line)
	ember	*script;
	void	*ptr;
	char	*file;
	int	line;
{
#	ifdef EMBER_MALLOC_DEBUG
# 	undef free
	printf("Free(%d) at %s : %d\n",ptr,file,line);
	fflush(stdout);
#	endif
	free(ptr);
}

char *eMemRealStrdup(script, str, file, line)
	ember	*script;
	char	*str,
		*file;
	int	line;
{
	char	*buf;

#	ifdef EMBER_MALLOC_DEBUG
#  		undef strdup
#	endif
	buf = strdup(str);
	if(buf == NULL)
	{
		snprintf(script->errorMsg, EMBER_ERR_LEN,
			"Out of memory at line %d of %s for %d bytes",
			line, file, strlen(str));
	}

#	ifdef EMBER_MALLOC_DEBUG
	printf("strdup('%s') = %d at %s : %d\n",str,buf,file,line);
#	endif
	return(buf);
}
